String representation of numbers with suffix denoting
K for thousands,Mn for millions, Bn for billions, Tn for trillions.
A number lower than thousand is represented as it is.
Arguments
number
an integer or double.
digits
number of digits to round-off. Default value is 1.
unit
unit to which the number to be converted. See examples below.
unit_labels
a vector of strings (optional) that gives the unit label
for thousand, million, billion and trillion.
prefix
a string (optional) that can be prepended to the formatted
number.
suffix
a string (optional) that can be appended at the end of the
formatted number.
thousand_separator
a character (optional) that can be used to chunk
thousands to display large numbers. Default is set as comma, dot, comma or
underscore can be used.